@@ -1,19 +1,16 @@
 import datetime
-import logging
 import typing
 
 import more_itertools
 import pendulum
 
 from .collection import Collection
-from .feeds import RSSFeed, RSSFeedItem
 from .page import Page
 
 
 class BlogPost(Page):
     """Page Like object with slight modifications to work with BlogPosts."""
 
-    template = "blog_post.html"
     list_attrs = ["tags"]
 
     def __init__(self, **kwargs):
@@ -30,7 +27,6 @@ class BlogPost(Page):
         """
 
         super().__init__(**kwargs)
-
         date_published = more_itertools.first_true(
             (
                 getattr(self, "date_published", None),
@@ -66,10 +62,6 @@ class BlogPost(Page):
 
         self.date_friendly = self.date_modified.format("MMM DD, YYYY HH:mm A")
 
-    @property
-    def rss_feed_item(self):
-        return RSSFeedItem(self)
-
 
 class Blog(Collection):
     """
@@ -81,10 +73,5 @@ class Blog(Collection):
     """
 
     content_type: typing.Type[BlogPost] = BlogPost
-    archive_reverse: bool = True
-    has_archive: bool = True
-    archive_sort = "date_published"
-
-    @property
-    def feeds(self):
-        return [RSSFeed(collection=self, title=self.title)]
+    sort_reverse: bool = True
+    sort_by = "date_published"
